@@ -1,6 +1,6 @@
 package Sort::Key::Natural;
 
-our $VERSION = '0.04';
+our $VERSION = '0.01';
 
 require Exporter;
 
@@ -9,11 +9,7 @@ our @EXPORT_OK = qw( natkeysort
 		     natkeysort_inplace
 		     rnatkeysort
 		     rnatkeysort_inplace
-		     mkkey_natural
-		     natsort
-		     rnatsort
-		     natsort_inplace
-		     rnatsort_inplace );
+		     mkkey_natural );
 
 sub mkkey_natural {
     my $nat = @_ ? shift : $_;
@@ -36,9 +32,6 @@ use Sort::Key::Register nat => \&mkkey_natural, 'string';
 
 use Sort::Key::Maker natkeysort => 'nat';
 use Sort::Key::Maker rnatkeysort => '-nat';
-use Sort::Key::Maker natsort => \&mkkey_natural, 'str';
-use Sort::Key::Maker rnatsort => \&mkkey_natural, '-str';
-
 1;
 
 =head1 NAME
@@ -47,29 +40,23 @@ Sort::Key::Natural - fast natural sorting
 
 =head1 SYNOPSIS
 
-    use Sort::Key::Natural qw(natsort);
+    use Sort::Key::Natural 'natkeysort';
 
     my @data = qw(foo1 foo23 foo6 bar12 bar1
-		  foo bar2 bar-45 foomatic b-a-r-45);
+		  foo bar2 bar-45 b-a-r-45);
 
-    my @sorted = natsort @data;
+    my @sorted = natkeysort { $_ } @data;
 
     print "@sorted\n";
     # prints:
-    #   b-a-r-45 bar1 bar2 bar12 bar-45 foo foo1 foo6 foo23 foomatic
-
-    use Sort::Key::Natural qw(natkeysort);
-
-    my @objects = (...);
-    my @sorted = natkeysort { $_->get_id } @objects;
-
+    #   b-a-r-45 bar1 bar2 bar12 bar-45 foo foo1 foo6 foo23
 
 =head1 DESCRIPTION
 
-This module extends the L<Sort::Key> family of modules to support
-natural sorting.
+This module extends the Sort::Key family of modules to support natural
+sorting.
 
-Under natural sorting, strings are splitted at word and number
+Under natural sorting, strings are splitted in word and number
 boundaries, and the resulting substrings are compared as follows:
 
 =over 4
@@ -93,12 +80,7 @@ splitting the string into its parts but not for sorting. For instance
 C<foo-bar-42> is broken in three substrings C<foo>, C<bar> and C<42>
 and after that the dashes are ignored.
 
-Note, that the sorting is case sensitive. To do a case insensitive
-sort you have to convert the keys explicitly:
-
-  my @sorted = natkeysort { lc $_ } @data
-
-Also, once this module is loaded, the new type C<natural> (or C<nat>) will
+Once this module is loaded, the new type C<natural> (or C<nat>) will
 be available from L<Sort::Key::Maker>. For instance:
 
   use Sort::Key::Natural;
@@ -114,35 +96,23 @@ the functions that can be imported from this module are:
 
 =over 4
 
-=item natsort @data
+=item natkeysort { CALC_KEY($_) } @data;
 
-returns the elements of C<@data> sorted in natural order.
+returns the elements on C<@array> naturally sorted by the key
+resulting from applying C<CALC_KEY> to them.
 
-=item rnatsort @data
+=item rnatkeysort { CALC_KEY($_) } @data;
 
-returns the elements of C<@data> sorted in natural descending order.
-
-=item natkeysort { CALC_KEY($_) } @data
-
-returns the elements on C<@array> naturally sorted by the keys
-resulting from applying them C<CALC_KEY>.
-
-=item rnatkeysort { CALC_KEY($_) } @data
-
-is similar to C<natkeysort> but sorts the elements in descending
+is similar to C<natkeysort> but sorting the elements on descending
 order.
 
-=item natsort_inplace @data
+=item natkeysort_inplace { CALC_KEY($_) } @data;
 
-=item rnatsort_inplace @data
+=item rnatkeysort_inplace { CALC_KEY($_) } @data;
 
-=item natkeysort_inplace { CALC_KEY($_) } @data
+these functions are similar to C<natsortkey> and C<rnatsortkey> but
+sort the array C<@data> in place.
 
-=item rnatkeysort_inplace { CALC_KEY($_) } @data
-
-these functions are similar respectively to C<natsort>, C<rnatsort>,
-C<natsortkey> and C<rnatsortkey>, but they sort the array C<@data> in
-place.
 
 =item mkkey_natural $key
 
@@ -156,7 +126,7 @@ provided it defaults to C<$_>
 
 L<Sort::Key>, L<Sort::Key::Maker>.
 
-Other module providing similar functionality is L<Sort::Naturally>.
+Other module providing similar functionality is L<Sort::Natural>.
 
 =head1 COPYRIGHT AND LICENSE
 
